#!/usr/bin/env python

"""Setup script for the (patched) curses module distribution."""

from distutils.core import setup, Extension

setup (# Distribution meta-data
       name = "jack_curses",
       version = "1.5b1",
       description = "standard curses module, patched to include newpad() and resizeterm()",
       author = "Arne Zellentin (just for the patch!)",
       author_email = "zarne@users.sf.net",
       url = "http://www.home.unix-ag.org/arne/jack/",

       # Description of the modules and packages in the distribution
       ext_modules = [ Extension('jack_cursesmodule', ['cursesmodule/jack_cursesmodule.c'], libraries=["ncurses"], extra_compile_args=["-Wno-strict-prototypes"]) ]
      )
